"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Ajv = require("ajv");
function addCustomKeywords(ajv, customKeywords) {
    customKeywords.forEach(function (kw) {
        if (Array.isArray(kw)) {
            addCustomKeywords(ajv, kw);
        }
        else {
            ajv.addKeyword(kw.name, kw);
        }
    });
}
var Validator = /** @class */ (function () {
    function Validator(options) {
        if (options === void 0) { options = {}; }
        this.ajv = new Ajv(options);
        if (options.customKeywords) {
            addCustomKeywords(this.ajv, options.customKeywords);
        }
    }
    Validator.prototype.validate = function (schema, obj) {
        var validate = this.ajv.compile(schema.toJSON());
        var coercedValue = {};
        var isValid = validate(obj, undefined, coercedValue, 'result');
        if (isValid) {
            return { errors: null, result: coercedValue.result !== undefined ? coercedValue.result : obj, valid: true };
        }
        else {
            return { errors: validate.errors, result: null, valid: false };
        }
    };
    return Validator;
}());
exports.Validator = Validator;
